"use strict";
//@ts-nocheck
const JavaFile = Java.type("java.io.File");
const JavaClass = Java.type("java.lang.Class");
const Thread = Java.type("java.lang.Thread");
const URLClassLoader = Java.type("java.net.URLClassLoader");
const Files = Java.type("java.nio.file.Files");
const StandardOpenOption = Java.type("java.nio.file.StandardOpenOption");
const Base64 = Java.type("java.util.Base64");
const LiquidBounce = Java.type("net.ccbluex.liquidbounce.LiquidBounce");
const ScriptManager = Java.type("net.ccbluex.liquidbounce.script.ScriptManager");
const script = registerScript({
    name: "mumyStrongholdFinder",
    version: "0.1",
    authors: ["mumy++"]
});
class StrongholdFinder {
    static DEVELOPER_MODE = false;
    static FILE_BASE64 = "";
    static DIRECTORY = new JavaFile(ScriptManager.INSTANCE.getScriptsRoot(), `lib\\mumyScript\\${script.scriptName} ${script.scriptVersion}`);
    static FILE = new JavaFile(this.DIRECTORY, `${script.scriptName}-${script.scriptVersion}${this.DEVELOPER_MODE ? "-dev" : ""}.jar`);
    static classLoader;
    static instance;
    static {
        try {
            this.classLoader = new URLClassLoader([this.FILE.toURL()], Thread.currentThread().getContextClassLoader());
        }
        catch (error) {
            LiquidBounce.INSTANCE.getLogger().error(`[${script.scriptName}] Exception!`, error);
        }
    }
    static load() {
        try {
            if (!this.DIRECTORY.exists() || !this.DIRECTORY.isDirectory()) {
                this.DIRECTORY.mkdirs();
            }
            this.release();
            const clazz = this.classLoader.loadClass("dev.mumy.Script");
            this.instance = clazz.getField("INSTANCE").get(null);
            this.instance.validate(script);
            this.instance.enable();
        }
        catch (error) {
            LiquidBounce.INSTANCE.getLogger().error(`[${script.scriptName}] Exception!`, error);
        }
    }
    static unload() {
        this.instance.disable();
        this.classLoader.close();
    }
    static release() {
        if (this.FILE_BASE64.length === 0) {
            return;
        }
        if (!this.FILE.exists() || !this.FILE.isFile() || this.DEVELOPER_MODE) {
            LiquidBounce.INSTANCE.getLogger().info(`[${script.scriptName}] Release file.`);
            Files.write(this.FILE.toPath(), Base64.getDecoder().decode(this.FILE_BASE64), StandardOpenOption.CREATE, StandardOpenOption.WRITE, StandardOpenOption.TRUNCATE_EXISTING);
        }
    }
}
script.on("enable", () => {
    StrongholdFinder.load();
});
script.on("disable", () => {
    StrongholdFinder.unload();
});
